@@ -21,6 +21,7 @@ from __future__ import division
 
 import datetime
 
+
 TEXT_RESULT_LENGTH = 42
 
 
@@ -183,7 +184,21 @@ class Day(object):
         return len(self.get_words(with_special_chars=True))
 
 
-    def search(self, text):
+    def search(self, text, tags):
+        if not text:
+            results = []
+            for day_tag in self.categories:
+                for tag in tags:
+                    if day_tag.replace(' ', '').lower() != tag:
+                        continue
+                    entries = self.get_entries(day_tag)
+                    if entries:
+                        results.extend(entries)
+                    else:
+                        results.append(get_text_with_dots(self.text, 0,
+                                       TEXT_RESULT_LENGTH))
+            return str(self), results
+
         results = []
         # Search in date
         if text in str(self):
@@ -257,9 +272,6 @@ class Month(object):
             self.days[day_number] = new_day
             return new_day
 
-    def set_day(self, day_number, day):
-        self.days[day_number] = day
-
     def __str__(self):
         res = 'Month %s %s\n' % (self.year_number, self.month_number)
         for day_number, day in self.days.iteritems():
