@@ -19,18 +19,18 @@
 
 from __future__ import division
 
+from collections import defaultdict
+import locale
 import logging
 import re
-import sys
 
 import gtk
 import gobject
 
 from rednotebook.gui.browser import HtmlView
-from rednotebook.util import unicode
 
 
-CLOUD_WORDS = 50
+CLOUD_WORDS = 30
 
 CLOUD_CSS = """\
 <style type="text/css">
@@ -43,6 +43,9 @@ CLOUD_CSS = """\
     a:focus { color:black; text-decoration:none; }
     a:hover { color:black; text-decoration:none; }
     a:active { color:black; text-decoration:none; }
+    h1 { border-bottom: 1px solid grey; margin: 0; margin-bottom: 8px;
+         padding: 0; font-size: 15px; line-height: 1; text-align: left;
+         font-weight: normal; }
 </style>
 """
 
@@ -55,66 +58,6 @@ def get_regex(word):
         return re.compile('^$')
 
 
-def get_cloud_html(word_count_dict, categories, ignores, includes):
-    words = word_count_dict.items()
-
-    # filter short words
-    words = [(word, freq) for (word, freq) in words
-             if len(word) > 4 or word in categories or
-             any(pattern.match(word) for pattern in includes)]
-
-    # filter words in ignore_list
-    words = [(word, freq) for (word, freq) in words
-             if not any(pattern.match(word) for pattern in ignores)]
-
-    def frequency((word, freq)):
-        # We want the categories to be included no matter their frequency
-        if word in categories:
-            return sys.maxint
-        return freq
-
-    # only take the longest words. If there are less words than n,
-    # len(words) words are returned
-    words.sort(key=frequency)
-    cloud_words = words[-CLOUD_WORDS:]
-
-    if not cloud_words:
-        return [], ''
-
-    counts = [freq for (word, freq) in cloud_words]
-    min_count = min(counts)
-    delta_count = max(counts) - min_count
-    if delta_count == 0:
-        delta_count = 1
-
-    min_font_size = 10
-    max_font_size = 50
-
-    font_delta = max_font_size - min_font_size
-
-    # sort words with unicode sort function
-    cloud_words.sort(key=lambda (word, count): unicode.coll(word))
-
-    html_elements = []
-
-    for index, (word, count) in enumerate(cloud_words):
-        font_factor = (count - min_count) / delta_count
-        font_size = int(min_font_size + font_factor * font_delta)
-
-        if word in categories:
-            word = '<u><b>%s</b></u>' % word
-
-        # Add some whitespace to separate words
-        html_elements.append('<a href="search/%s">'
-                             '<span style="font-size:%spx">%s</span></a>&#160;'
-                             % (index, font_size, word))
-
-    html_body = ''.join(['<body>', '\n'.join(html_elements), '\n</body>\n'])
-    html_doc = ''.join(['<html><head>', CLOUD_CSS, '</head>', html_body, '</html>'])
-
-    return (cloud_words, html_doc)
-
-
 class Cloud(HtmlView):
     def __init__(self, journal):
         HtmlView.__init__(self)
@@ -160,19 +103,98 @@ class Cloud(HtmlView):
 
         gobject.idle_add(self._update)
 
+    def get_categories_counter(self):
+        counter = defaultdict(int)
+        for day in self.journal.days:
+            for cat in day.categories:
+                counter[cat.replace(' ', '').lower()] += 1
+        return counter
+
     def _update(self):
         logging.debug('Update the cloud')
         self.journal.save_old_day()
 
-        word_count_dict = self.journal.get_word_count_dict()
-        self.cloud_words, html = get_cloud_html(word_count_dict,
-            self.journal.categories, self.regexes_ignore, self.regexes_include)
+        def cmp_words((word1, freq1), (word2, freq2)):
+            # TODO: Use key=locale.strxfrm in python3
+            return locale.strcoll(word1, word2)
 
+        self.link_index = 0
+        word_count_dict = self.journal.get_word_count_dict()
+        self.tags = sorted(self.get_categories_counter().items(), cmp=cmp_words)
+        self.words = self._get_words_for_cloud(word_count_dict,
+                                    self.regexes_ignore, self.regexes_include)
+        self.words.sort(cmp=cmp_words)
+        self.link_dict = self.tags + self.words
+        html = self.get_clouds(self.words, self.tags)
         self.load_html(html)
         self.last_hovered_word = None
-
         logging.debug('Cloud updated')
 
+    def _get_cloud_body(self, cloud_words):
+        if not cloud_words:
+            return ''
+        counts = [freq for (word, freq) in cloud_words]
+        min_count = min(counts)
+        delta_count = max(counts) - min_count
+        if delta_count == 0:
+            delta_count = 1
+
+        min_font_size = 10
+        max_font_size = 40
+
+        font_delta = max_font_size - min_font_size
+
+        html_elements = []
+
+        for word, count in cloud_words:
+            font_factor = (count - min_count) / delta_count
+            font_size = int(min_font_size + font_factor * font_delta)
+
+            # Add some whitespace to separate words
+            html_elements.append('<a href="search/%s">'
+                                 '<span style="font-size:%spx">%s</span></a>&#160;'
+                                 % (self.link_index, font_size, word))
+            self.link_index += 1
+        return '\n'.join(html_elements)
+
+    def _get_words_for_cloud(self, word_count_dict, ignores, includes):
+        # filter short words
+        words = [(word, freq) for (word, freq) in word_count_dict.items()
+                 if (len(word) > 4 or
+                 any(pattern.match(word) for pattern in includes)) and not
+                 # filter words in ignore_list
+                 any(pattern.match(word) for pattern in ignores)]
+
+        def frequency((word, freq)):
+            return freq
+
+        # only take the longest words. If there are less words than n,
+        # len(words) words are returned
+        words.sort(key=frequency)
+        return words[-CLOUD_WORDS:]
+
+    def get_clouds(self, word_counter, tag_counter):
+        tag_cloud = self._get_cloud_body(tag_counter)
+        word_cloud = self._get_cloud_body(word_counter)
+        heading = '<h1>&#160;%s</h1>'
+        parts = ['<html><head>', CLOUD_CSS, '</head>', '<body>']
+        if tag_cloud:
+            parts.extend([heading % _('Tags'), tag_cloud, '\n',
+                          '<br />\n' * 3])
+        if word_cloud:
+            parts.extend([heading % _('Words'), word_cloud])
+        parts.append('</body></html>')
+        return '\n'.join(parts)
+
+    def _get_search_text(self, uri):
+        # uri has the form "something/somewhere/search/search_index"
+        search_index = int(uri.split('/')[-1])
+        search_text, count = self.link_dict[search_index]
+        # Treat tags separately
+        if search_index < len(self.tags):
+            search_text = u'#' + search_text
+        return search_text
+
     def on_navigate(self, webview, frame, request):
         """
         Called when user clicks on a cloud word
@@ -188,10 +210,7 @@ class Cloud(HtmlView):
 
         # uri has the form "something/somewhere/search/search_index"
         if 'search' in uri:
-            # search_index is the part after last slash
-            search_index = int(uri.split('/')[-1])
-            search_text, count = self.cloud_words[search_index]
-
+            search_text = self._get_search_text(uri)
             self.journal.frame.search_box.set_active_text(search_text)
 
             # returning True here stops loading the document
@@ -210,9 +229,7 @@ class Cloud(HtmlView):
         to the context menu when the user right-clicks the next time
         """
         if uri:
-            search_index = int(uri.split('/')[-1])
-            search_text, count = self.cloud_words[search_index]
-            self.last_hovered_word = search_text
+            self.last_hovered_word = self._get_search_text(uri)
 
     def on_populate_popup(self, webview, menu):
         """Called when the cloud's popup menu is created."""
