@@ -34,8 +34,8 @@ from rednotebook import templates
 from rednotebook.util import markup
 from rednotebook.util import dates
 from rednotebook import undo
-from rednotebook.gui.exports import ExportAssistant
 from rednotebook.gui import categories
+from rednotebook.gui.exports import ExportAssistant
 from rednotebook.gui import browser
 from rednotebook.gui import search
 from rednotebook.gui.editor import Editor
@@ -116,12 +116,10 @@ class MainWindow(object):
         self.html_editor.hide()
         self.html_editor.set_editable(False)
         self.preview_mode = False
-        self.preview_button = self.builder.get_object('preview_button')
 
         # Let the edit_paned respect its childs size requests
-        edit_paned = self.builder.get_object('edit_pane')
         text_vbox = self.builder.get_object('text_vbox')
-        edit_paned.child_set_property(text_vbox, 'shrink', False)
+        self.edit_pane.child_set_property(text_vbox, 'shrink', False)
 
         self.load_values_from_config()
 
@@ -470,7 +468,7 @@ class MainWindow(object):
         dir_chooser.hide()
 
         if response == gtk.RESPONSE_OK:
-            dir = dir_chooser.get_current_folder()
+            dir = dir_chooser.get_current_folder().decode('utf-8')
 
             if type == 'saveas':
                 self.journal.dirs.data_dir = dir
@@ -515,7 +513,7 @@ class MainWindow(object):
         left_div = self.builder.get_object('main_pane').get_position()
         config['leftDividerPosition'] = left_div
 
-        right_div = self.builder.get_object('edit_pane').get_position()
+        right_div = self.edit_pane.get_position()
         config['rightDividerPosition'] = right_div
 
         # Remember if window was maximized in separate method
@@ -561,7 +559,7 @@ class MainWindow(object):
 
         if 'leftDividerPosition' in config:
             self.builder.get_object('main_pane').set_position(config.read('leftDividerPosition', -1))
-        self.builder.get_object('edit_pane').set_position(config.read('rightDividerPosition', 500))
+        self.edit_pane.set_position(config.read('rightDividerPosition', 500))
 
         # A font size of -1 applies the standard font size
         main_font_size = config.read('mainFontSize', -1)
@@ -848,8 +846,8 @@ class MainWindow(object):
         picture_chooser.hide()
 
         if response == gtk.RESPONSE_OK:
-            dirs.last_pic_dir = picture_chooser.get_current_folder()
-            base, ext = os.path.splitext(picture_chooser.get_filename())
+            dirs.last_pic_dir = picture_chooser.get_current_folder().decode('utf-8')
+            base, ext = os.path.splitext(picture_chooser.get_filename().decode('utf-8'))
 
             # On windows firefox accepts absolute filenames only
             # with the file:/// prefix
@@ -866,8 +864,8 @@ class MainWindow(object):
         file_chooser.hide()
 
         if response == gtk.RESPONSE_OK:
-            dirs.last_file_dir = file_chooser.get_current_folder()
-            filename = file_chooser.get_filename()
+            dirs.last_file_dir = file_chooser.get_current_folder().decode('utf-8')
+            filename = file_chooser.get_filename().decode('utf-8')
             filename = filesystem.get_local_url(filename)
             head, tail = os.path.split(filename)
             # It is always safer to add the "file://" protocol and the ""s
@@ -923,12 +921,7 @@ class MainWindow(object):
         return self.day_text_field.get_text()
 
     def highlight_text(self, search_text):
-        # let the search function highlight found strings in the page
-        #if self.preview_mode:
-            # If we search twice on the same day, the html is not reloaded
-            # so we have to manually highlight
         self.html_editor.highlight(search_text)
-        #else:
         self.day_text_field.highlight(search_text)
 
 
@@ -978,6 +971,11 @@ class DayEditor(Editor):
         self.day = new_day
         self.set_text(self.day.text, undoing=True)
 
+        if self.search_text:
+            # If a search is currently made, scroll to the text and return.
+            gobject.idle_add(self.scroll_to_text, self.search_text)
+            return
+
         if self.day.last_edit_pos is not None:
             x, y, selection = self.day.last_edit_pos
             gobject.idle_add(self.scrolled_win.get_hscrollbar().set_value, x)
