@@ -19,6 +19,7 @@
 
 from xml.sax.saxutils import escape
 
+import gobject
 import gtk
 
 from rednotebook.gui.customwidgets import CustomComboBoxEntry
@@ -38,8 +39,6 @@ class SearchComboBox(CustomComboBoxEntry):
         self.entry.connect('changed', self.on_entry_changed)
         self.entry.connect('activate', self.on_entry_activated)
 
-        self.recent_searches = []
-
     def on_entry_changed(self, entry):
         """Called when the entry changes."""
         self.search(self.get_active_text())
@@ -47,21 +46,29 @@ class SearchComboBox(CustomComboBoxEntry):
     def on_entry_activated(self, entry):
         """Called when the user hits enter."""
         search_text = entry.get_text()
-
-        self.recent_searches.append(search_text)
-        self.recent_searches = self.recent_searches[-20:]
         self.add_entry(search_text)
-
         self.search(search_text)
 
     def search(self, search_text):
-        # Tell the webview which text to highlight after the html is loaded
-        self.main_window.html_editor.search_text = search_text
+        tags = []
+        queries = []
+        for part in search_text.split():
+            if part.startswith(u'#'):
+                tags.append(part.lstrip(u'#').lower())
+            else:
+                queries.append(part)
+
+        search_text = ' '.join(queries)
 
         # Highlight all occurences in the current day's text
         self.main_window.highlight_text(search_text)
 
-        self.main_window.search_tree_view.update_data(search_text)
+        # Scroll to query.
+        if search_text:
+            gobject.idle_add(self.main_window.day_text_field.scroll_to_text,
+                             search_text)
+
+        self.main_window.search_tree_view.update_data(search_text, tags)
 
 
 class SearchTreeView(gtk.TreeView):
@@ -70,9 +77,6 @@ class SearchTreeView(gtk.TreeView):
         self.main_window = main_window
         self.journal = self.main_window.journal
 
-        # Normally unneeded, but just to be sure everything works fine
-        self.searched_text = ''
-
         # create a TreeStore with two string columns to use as the model
         self.tree_store = gtk.ListStore(str, str)
 
@@ -106,20 +110,17 @@ class SearchTreeView(gtk.TreeView):
 
         self.connect('cursor_changed', self.on_cursor_changed)
 
-    def update_data(self, search_text=''):
+    def update_data(self, search_text, tags):
         self.tree_store.clear()
 
-        if not search_text:
+        if not tags and not search_text:
             self.main_window.cloud.show()
             self.parent.hide()
             return
         self.main_window.cloud.hide()
         self.parent.show()
 
-        # Save the search text for highlighting
-        self.searched_text = search_text
-
-        for date_string, entries in self.journal.search(search_text):
+        for date_string, entries in self.journal.search(search_text, tags):
             for entry in entries:
                 entry = escape(entry)
                 entry = entry.replace('STARTBOLD', '<b>').replace('ENDBOLD', '</b>')
@@ -127,12 +128,9 @@ class SearchTreeView(gtk.TreeView):
 
     def on_cursor_changed(self, treeview):
         """Move to the selected day when user clicks on it"""
-        selection = self.get_selection()
-        model, paths = selection.get_selected_rows()
+        model, paths = self.get_selection().get_selected_rows()
         if not paths:
             return
         date_string = self.tree_store[paths[0]][0]
         new_date = dates.get_date_from_date_string(date_string)
         self.journal.change_date(new_date)
-
-        self.main_window.highlight_text(self.searched_text)
