@@ -17,15 +17,13 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 # -----------------------------------------------------------------------
 
-import os
-
-# For testing
+# This is required for setup.py to be able to import this module.
 import __builtin__
 if not hasattr(__builtin__, '_'):
     def _(string):
         return string
 
-version =           '1.3.0'
+version =           '1.4.0'
 author =            'Jendrik Seipp'
 authorMail =        'jendrikseipp@web.de'
 url =               'http://rednotebook.sourceforge.net'
@@ -33,11 +31,7 @@ answers_url =       'https://answers.launchpad.net/rednotebook'
 translation_url =   'https://translations.launchpad.net/rednotebook/'
 bug_url =           'https://bugs.launchpad.net/rednotebook/+filebug'
 
-developers =    ['Jendrik Seipp <jendrikseipp@web.de>',
-                '',
-                'Past Contributors:',
-                'Alexandre Cucumel <superkiouk@gmail.com>',
-                ]
+developers =    ['Jendrik Seipp <jendrikseipp@web.de>']
 
 comments = '''\
 RedNotebook is a graphical journal to keep track of notes and
@@ -304,11 +298,17 @@ from inside RedNotebook by opening the menu next to the "Template" button.
 On the left you find the search box. Double-clicking on a day in the search
 results lets you jump to it.
 
-== Clouds ==
+== Clouds ==[clouds]
 If a word appears in the cloud that you don't want to see there, just right-click
 and select to hide it.
 Alternatively you can open the Preferences dialog and add the word to the cloud blacklist.
 Short words with less than 5 letters can be white-listed there as well.
+[Regular expressions http://docs.python.org/library/re.html] are allowed in the
+lists.
+
+You can **hide the word cloud** by adding the regular expression .* to the
+blacklist. This will filter out all words.
+
 
 == Spellcheck ==
 RedNotebook supports spellchecking your entries if you have
@@ -646,32 +646,3 @@ Type=Application
 Categories=Office;
 StartupNotify=true
 '''
-
-def write_documentation(dir):
-    '''
-    Write the documenation as html to a directory
-    Include the original markup as "source.txt"
-    '''
-    from rednotebook.util import filesystem
-    from rednotebook.util import markup
-
-    filesystem.write_file(os.path.join(dir, 'source.txt'), help_text)
-    headers = [_('RedNotebook Documentation'), version, '']
-    options = {'toc': 1,}
-    html = markup.convert(help_text, 'xhtml', headers, options)
-    filesystem.write_file(os.path.join(dir, 'help.html'), html)
-
-if __name__ == '__main__':
-    import sys
-    sys.path.insert(0, os.path.abspath("./../"))
-
-    print completeWelcomeText
-    print '*'*80
-    print help_text
-
-    doc_dir = '../doc'
-    doc_dir = os.path.abspath(doc_dir)
-
-    write_documentation(doc_dir)
-
-    #logging.getLogger('').setLevel(logging.DEBUG)
