@@ -108,20 +108,15 @@ options, args = parse_options()
 ## ---------------------- Enable logging -------------------------------
 
 def setup_logging(log_file):
-    #logging_levels = {'debug': logging.DEBUG,
-    #               'info': logging.INFO,
-    #               'warning': logging.WARNING,
-    #               'error': logging.ERROR,
-    #               'critical': logging.CRITICAL}
-
-    # File logging
-    if sys.platform == 'win32' and hasattr(sys, "frozen"):
-        utils.redirect_output_to_file(log_file)
-
     file_logging_stream = open(log_file, 'w')
 
-    # We want to have the error messages in the logfile
-    sys.stderr = utils.StreamDuplicator(sys.__stderr__, [file_logging_stream])
+    # We want to have the error messages in the logfile. In the frozen
+    # version we cannot log to sys.stderr because it's broken on
+    # windows. Stdout is redirected into a blackhole by py2exe.
+    stderr_streams = [file_logging_stream]
+    if not hasattr(sys, 'frozen'):
+        stderr_streams.append(sys.__stderr__)
+    sys.stderr = utils.StreamDuplicator(stderr_streams)
 
     root_logger = logging.getLogger('')
     root_logger.setLevel(logging.DEBUG)
@@ -336,7 +331,7 @@ class Journal:
 
         if something_saved:
             self.show_message(_('The content has been saved to %s') % self.dirs.data_dir, error=False)
-            logging.info('The content has been saved to %s' % self.dirs.data_dir)
+            logging.info('The content has been saved to %r' % self.dirs.data_dir)
         else:
             self.show_message(_('Nothing to save'), error=False)
 
@@ -358,7 +353,7 @@ class Journal:
         # Password Protection
         #password = self.config.read('password', '')
 
-        logging.info('Opening journal at %s' % data_dir)
+        logging.info('Opening journal at %r' % data_dir)
 
         if not os.path.exists(data_dir):
             logging.warning('The data dir %s does not exist. Select a different dir.'
@@ -385,8 +380,6 @@ class Journal:
 
         self.stats = Statistics(self)
 
-        self.frame.categories_tree_view.categories = self.categories
-
         if self.is_first_start and data_dir_empty and len(self.days) == 0:
             self.add_instruction_content()
 
@@ -395,6 +388,11 @@ class Journal:
         # Reset Search
         self.frame.search_box.clear()
 
+        self.frame.categories_tree_view.categories = self.categories
+        # Add auto-completion for tag search
+        self.frame.search_box.set_entries([u'#%s' % self.normalize_tag(tag)
+                                           for tag in self.categories])
+
         self.title = filesystem.get_journal_title(data_dir)
 
         # Set frame title
@@ -504,6 +502,10 @@ class Journal:
                            key=utils.sort_asc))
 
 
+    def normalize_tag(self, tag):
+        return tag.replace(' ', '').lower()
+
+
     def get_entries(self, category):
         entries = set()
         for day in self.days:
@@ -511,13 +513,25 @@ class Journal:
         return sorted(entries)
 
 
-    def search(self, text):
+    def search(self, text, tags):
+        days = self.get_days_with_tags(tags)
         results = []
-        for day in reversed(self.days):
-            results.append(day.search(text))
+        for day in reversed(days):
+            results.append(day.search(text, tags))
         return results
 
 
+    def get_days_with_tags(self, tags):
+        if not tags:
+            return self.days
+        days = []
+        for day in self.days:
+            day_tags = [tag.replace(' ', '').lower() for tag in day.categories]
+            if all(tag in day_tags for tag in tags):
+                days.append(day)
+        return days
+
+
     def get_word_count_dict(self):
         '''
         Returns a dictionary mapping the words to their number of appearance
