@@ -20,6 +20,7 @@
 from __future__ import with_statement
 
 import logging
+import os
 import re
 import sys
 
@@ -40,7 +41,6 @@ REGEX_LINEBREAK = r'\\\\[\s]*$'
 REGEX_HTML_LINK = r'<a.*?>(.*?)</a>'
 
 TABLE_HEAD_BG = '#aaa'
-BLOCKQUOTE_BG = '#ccc'
 
 CHARSET_UTF8 = '<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />'
 
@@ -84,16 +84,33 @@ CSS = """\
 </style>
 """ % globals()
 
+# MathJax
+MATHJAX_FILE = '/usr/share/javascript/mathjax/MathJax.js'
+FORMULAS_SUPPORTED = True
+if not os.path.isfile(MATHJAX_FILE):
+    MATHJAX_FILE = 'http://cdn.mathjax.org/mathjax/latest/MathJax.js'
+logging.info('MathJax location: %s' % MATHJAX_FILE)
+
 MATHJAX = """\
 <script type="text/x-mathjax-config">
-MathJax.Hub.Config({
-  tex2jax: {inlineMath: [['$','$']]}
-});
+  MathJax.Hub.Config({
+  config: ["MMLorHTML.js"],
+  jax: ["input/TeX","input/MathML","output/HTML-CSS","output/NativeMML"],
+  tex2jax: {
+      inlineMath: [ ['$','$'] ],
+      displayMath: [ ['$$','$$'] ],
+      processEscapes: true
+    },
+  extensions: ["tex2jax.js","mml2jax.js","MathMenu.js","MathZoom.js"],
+  TeX: {
+    extensions: ["AMSmath.js","AMSsymbols.js","noErrors.js","noUndefined.js"]
+  }
+  });
 </script>
 <script type="text/javascript"
-  src="https://d3eoax9i5htok0.cloudfront.net/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML">
+  src="%s">
 </script>
-"""
+""" % (MATHJAX_FILE)
 
 
 def convert_categories_to_markup(categories, with_category_title=True):
@@ -181,9 +198,6 @@ def _get_config(type):
         # Custom css
         config['postproc'].append([r'</head>', CSS + '</head>'])
 
-        # mathjax
-        #config['postproc'].append([r'</body>', MATHJAX + '</body>'])
-
         # Line breaks
         config['postproc'].append([r'LINEBREAK', '<br />'])
 
@@ -220,8 +234,10 @@ def _get_config(type):
         config['postproc'].append([r'includegraphics\{("?)WIDTH(\d+)-', r'includegraphics[width=\2px]{\1'])
 
         # We want the plain latex formulas unescaped
-        config['preproc'].append([r'\$\s*(.+?)\s*\$', r"BEGINFORMULA''\1''ENDFORMULA"])
-        config['postproc'].append([r'BEGINFORMULA(.+)ENDFORMULA', r'$\1$'])
+        config['preproc'].append([r'\$\$\s*(.+?)\s*\$\$', r"BEGINEQUATION''\1''ENDEQUATION"])
+        config['postproc'].append([r'BEGINEQUATION(.+)ENDEQUATION', r'$$\1$$'])
+        config['preproc'].append([r'\$\s*(.+?)\s*\$', r"BEGINMATH''\1''ENDMATH"])
+        config['postproc'].append([r'BEGINMATH(.+)ENDMATH', r'$\1$'])
 
     elif type == 'txt':
         # Line breaks
@@ -246,16 +262,25 @@ def convert(txt, target, headers=None, options=None):
     '''
     Code partly taken from txt2tags tarball
     '''
+    add_mathjax = FORMULAS_SUPPORTED and 'html' in target and '$' in txt
 
     # Here is the marked body text, it must be a list.
     txt = txt.split('\n')
 
     # Set the three header fields
     if headers is None:
-        headers = ['', '', '']
+        if target == 'tex':
+            # LaTeX requires a title if \maketitle is used
+            headers = ['RedNotebook', '', '']
+        else:
+            headers = ['', '', '']
 
     config = _get_config(target)
 
+    # MathJax
+    if add_mathjax:
+        config['postproc'].append([r'</body>', MATHJAX + '</body>'])
+
     config['outfile'] = txt2tags.MODULEOUT  # results as list
     config['target'] = target
 
