@@ -19,7 +19,6 @@
 
 from __future__ import with_statement, division
 
-import sys
 import signal
 import os
 import re
@@ -56,29 +55,6 @@ def set_environment_variables(config):
             logging.info('There is no environment variable called %s' % variable)
 
 
-def redirect_output_to_file(logfile_path):
-    """
-    Changes stdout and stderr to a file.
-    Disables both streams if logfile_path is None or cannot be opened.
-
-    This is necessary to suppress the error messages on Windows when closing
-    the application.
-    """
-    assert sys.platform == 'win32'
-
-    if logfile_path is None:
-        logfile = None
-    else:
-        try:
-            logfile = open(logfile_path, 'w')
-        except IOError:
-            logging.info('logfile %s could not be found, disabling output' % logfile_path)
-            logfile = None
-
-    sys.stdout = logfile
-    sys.stderr = logfile
-
-
 def setup_signal_handlers(journal):
     """
     Catch abnormal exits of the program and save content to disk
@@ -204,29 +180,23 @@ def show_html_in_browser(html, filename):
     webbrowser.open(html_file)
 
 
-
 class StreamDuplicator(object):
-    def __init__(self, default, duplicates):
-        if not type(duplicates) == list:
-            duplicates = [duplicates]
-        self.duplicates = duplicates
-        self.default = default
+    def __init__(self, streams):
+        self.streams = streams
 
-    @property
-    def streams(self):
-        return [self.default] + self.duplicates
-
-    def write(self, str):
+    def write(self, buf):
         for stream in self.streams:
-            stream.write(str)
+            stream.write(buf)
+            # If we don't flush here, stderr messages are printed late.
+            stream.flush()
 
     def flush(self):
         for stream in self.streams:
             stream.flush()
 
-    #def close(self):
-    #   for stream in self.streams():
-    #       self.stream.close()
+    def close(self):
+       for stream in self.streams():
+           self.stream.close()
 
 
 
